
===============
OpenCMISS Maths
===============

OpenCMISS maths functions.  This software can be found on PyPi and installed with the following command::

  pip install opencmiss.maths

Distribution
============

This software uses regex to extract the version number information from the package. The version number for this package is stored in 'src/opencmiss/maths/__init__.py'

